#!/bin/csh -f

echo " "
echo "WRFV3_fpt_experiment.csh"
echo "========================"
echo " "

if (! -e fpt_build_environment) then
	echo "This script must be run from the parent directory containing"
	echo "fpt_build_environment/.  Aborting"
	echo " "
	exit
endif

set WRFV3_VERSION = "$1"

set enetcdf = $?NETCDF
if ( $enetcdf == 0 ) then
	echo "This script will attempt a build of WRF."
	echo " "
	echo "The build requires NetCDF to be installed, and the symbol NETCDF to"
	echo "be defined as the main installation directory, so that the libraries"
	echo "reside in NETCDF/lib"
	echo " "
	echo "Please refer to https://www.unidata.ucar.edu/netcdf/dics/netcdf-install"
	echo "Install NetCDF and then repeat this setup"
	echo " "
	exit
endif

if ( ! -e ./fpt/${WRFV3_VERSION}_$2.fsp) then
	echo "Usage:"
	echo " "
	echo "$ tools/WRFV3_fpt_experiment.csh  WRF_version  experiment_name"
	echo " "
	echo "e.g."
	echo "$ tools/WRFV3_fpt_experiment.csh WRFV3.6.1 remove_intent"
	echo " "
	echo "Where WRF_version is the full WRF version and experiment_name is an fpt experiment."
	echo "The file ./fpt/WRF_version_experiment_name.fsp sets up the experiment"
	echo " "
	exit
endif

# Clean the fpt output directories
echo "Cleaning the fpt_output directories"
echo " "
# Note that we discard warnings that files to be deleted do not exist by rediricting 2>/dev/null
cd fpt_output
../tools/clean_all_fortran.csh s 2>/dev/null

echo "Launching fpt to prepare the build files"
echo "Note that fpt will report about 6200 (WRFV3.4.1) or about 10,000 (WRFV3.6.1) diagnostics"
echo " "
sleep 5
cd ../fpt
fpt "%paging off" ${WRFV3_VERSION}_$2.fsp
cd ..

# Copy the build files for comparison with UCAR_not_built/
echo " "
echo "Copying the fpt_output files for comparison with other experiments"
echo " "
if ( -e ${WRFV3_VERSION}_$2 ) then
	rm -R -f ${WRFV3_VERSION}_$2
endif
cp -R fpt_output ${WRFV3_VERSION}_$2

# Set up the build environment.  The "s" means "silent"
# Note that we discard warnings that files to be deleted do not exist by rediricting >& /dev/null
echo "Copying the fpt_output files to the build directories"
echo " "
tools/prepare_fpt_build_environment.csh $WRFV3_VERSION s >& /dev/null

# Build the new case
echo "Building wrf.exe using a slightly modified form of the UCAR build procedure"
echo "Note that the replacement of m4 by cpp for some files results in warnings for"
echo "un-matched string delimiters and redefined symbols.  These may safely be ignored."
echo " "
cd fpt_build_environment/WRFV3/
./compile em_b_wave > compile.log
cd main
echo "Renaming wrf.exe to wrf_$2.exe and moving it to run_tests/WRFV3/run/"
mv wrf.exe ../../../run_tests_${WRFV3_VERSION}/WRFV3/main/wrf_$2.exe

echo "Running wrf_$2.exe to generate the wrfout output"
echo " " 
# Change to the run_tests test directory
cd ../../../run_tests_${WRFV3_VERSION}/WRFV3/test/em_b_wave
# Set up the links for em_b_wave
./run_me_first.csh
cd ../../run/
if ( -e wrfout_${WRFV3_VERSION}_$2 ) then
	rm -f wrfout_${WRFV3_VERSION}_$2
endif
../main/ideal.exe
../main/wrf_$2.exe
echo " "
echo "Copying the output file to give it a suffix for the experiment"
echo " "
mv wrfout_d01_0001-01-01_00\:00\:00 wrfout_${WRFV3_VERSION}_$2

echo "Comparing the output with that generated by a UCAR build"
echo " "
diff --brief wrfout_${WRFV3_VERSION}_$2 wrfout_${WRFV3_VERSION}_UCAR
if ($status == 0) then
	echo "Output files are identical"
else
	echo "Output file differs from the UCAR standard build"
endif
echo " "
echo "End of WRFV3_fpt_experiment.csh"


